*******************************************************************************************************
* Program name: DANE_1_Data.do
* Program purpose: This program merges different SRU datasets over the years into one dataset and adds data on VAT rates, commodity groups and CPI prices in the Czech Republic
* Program created:   June 2011 - October 2013, by Petr Jansky as a part of the TACR OMEGA project and in cooperation with the IFS
*******************************************************************************************************

********** Set up file directories and globals ********************************************************
set more off
global folder "C:\Users\PJ\Desktop\IDEA\1107_Demand_system\Data"
cd "$folder\"
global sru "$folder\SRU_PJ"
global data "$folder\"
global cpi "$folder\CPI"
global years "2011 2010 2009 2008 2007 2006 2005 2004 2003 2002 2001" // some functioning SRU data from 1997 (in this format from 1999, representative data from 2006), some price data from 1991 (good from 2001)

********** Merge SR data from S ************************************************************
foreach y in $years { 
clear all
set memory 1G
insheet using "$sru/`y'/Ru`y'd.txt" 
sort zprav
save "$sru/`y'/Ru`y'd.dta", replace

clear all
set memory 1G
insheet using "$sru/`y'/Ru`y'e.txt" 
sort zprav
save "$sru/`y'/Ru`y'e.dta", replace

merge zprav using "$sru/`y'/Ru`y'd.dta"

* Editing SRU files
gen year = `y'
rename stzn sru
gen sru_2010 = sru
rename pocetmj amount
rename cenacelk exp
* Repearing the errors in the data
replace sru = 6980 if sru == 698 & `y' == 2010 & zprav == 2002012

* Definitions of regions/kraje and Praha
capture drop kraj
* Praha
gen kraj = 1 if (zprav > 1000000 & zprav < 1999999 & year >= 2001) | (zprav > 3100000 & zprav < 3199999 & year <= 2000) // 10   Hl. m. Praha (10 od 2005, 11 do 2004)
gen praha = 0
replace praha = 1 if kraj == 1
* Stedoesk kraj 
replace kraj = 2 if ((zprav > 2000000 & zprav < 2199999 & year >= 2001) | (zprav > 3200000 & zprav < 3299999 & year <= 2000)) // 20 od 2005, 21 do 2004
* Jihoesk kraj
replace kraj = 3 if ((zprav > 3100000 & zprav < 3199999 & year >= 2001) | (((zprav > 3300000 & zprav < 3303999)|(zprav > 3304999 & zprav < 3399999)) & year <= 2000)) // okresy bez Pelhrimova
* Plzesk kraj
replace kraj = 4 if ((zprav > 3200000 & zprav < 3299999 & year >= 2001) | (((zprav > 3400000 & zprav < 3401999)|(zprav > 3403999 & zprav < 3408999)|(zprav > 3409999 & zprav < 3499999)) & year <= 2000)) // Bez Chebu, Karlovch varu a Sokolova
* Karlovarsk kraj
replace kraj = 5 if (zprav > 4100000 & zprav < 4199999 & year >= 2001) | (((zprav > 3401999 & zprav < 3403999)|(zprav > 3408999 & zprav < 3409999)) & year <= 2000) // Karlovarsky kraj - Cheb, Karlovy vary a Sokolov
* steck kraj
replace kraj = 6 if (zprav > 4200000 & zprav < 4299999 & year >= 2001) | (((zprav > 3502000 & zprav < 3503999)|(zprav > 3505999 & zprav < 3599999)) & year <= 2000)
* Libereck kraj
replace kraj = 7 if (zprav > 5100000 & zprav < 5199999 & year >= 2001) | (((zprav > 3500000 & zprav < 3501999)|(zprav > 3503999 & zprav < 3505999)|(zprav > 3607999 & zprav < 3608999))& year <= 2000)
* Krlovhradeck kraj
replace kraj = 8 if (zprav > 5200000 & zprav < 5299999 & year >= 2001) | (((zprav > 3602000 & zprav < 3602999)|(zprav > 3603999 & zprav < 3605999)|(zprav > 3606999 & zprav < 3607999)|(zprav > 3609999 & zprav < 3610999))& year <= 2000)
* Pardubick kraj
replace kraj = 9 if (zprav > 5300000 & zprav < 5399999 & year >= 2001) | (((zprav > 3603000 & zprav < 3603999)|(zprav > 3605999 & zprav < 3606999)|(zprav > 3608999 & zprav < 3609999)|(zprav > 3610999 & zprav < 3611999)|(zprav > 3303999 & zprav < 3304999)|(zprav > 3600999 & zprav < 3601999))& year <= 2000)
* Vysoina
replace kraj = 10 if (((zprav > 6300000 & zprav < 6399999) | (zprav > 6100000 & zprav < 6199999)) & year >= 2001) | (((zprav > 3707000 & zprav < 3707999)|(zprav > 3709999 & zprav < 3710999)|(zprav > 3713999 & zprav < 3714999)|(zprav > 3610999 & zprav < 3611999))& year <= 2000) //63  Vysoina (od roku 2008: 63 - Vysoina (dve 61))
* Jihomoravsk kraj 
replace kraj = 11 if (((zprav > 6200000 & zprav < 6299999) | (zprav > 6400000 & zprav < 6499999)) & year >= 2001) | (((zprav > 3700000 & zprav < 3703999)|(zprav > 3705999 & zprav < 3706999)|(zprav > 3711999 & zprav < 3713999))& year <= 2000)  // 64   Jihomoravsk kraj (od roku 2008: 64   Jihomoravsk kraj (dve 62))
* Olomouck kraj
replace kraj = 12 if ((zprav > 7100000 & zprav < 7199999 & year >= 2001) | (((zprav > 3709000 & zprav < 3709999)|(zprav > 3804999 & zprav < 3805999)|(zprav > 3807999 & zprav < 3809999)|(zprav > 3810999 & zprav < 3811999))& year <= 2000))
* Zlnsk kraj
replace kraj = 13 if ((zprav > 7200000 & zprav < 7299999 & year >= 2001) | (((zprav > 3705000 & zprav < 3705999)|(zprav > 3707999 & zprav < 3708999)|(zprav > 3710999 & zprav < 3711999)|(zprav > 3809999 & zprav < 3810999)) & year <= 2000))
* Moravskoslezsk kraj
replace kraj = 14 if ((zprav > 8000000 & zprav < 8199999 & year >= 2001) | (((zprav > 3800000 & zprav < 3804999)|(zprav > 3805999 & zprav < 3807999)) & year <= 2000)) // 80   Moravskoslezsk kraj (80 od 2005, 81 do 2004)
sort sru
save "$sru/`y'/sru`y'.dta", replace
}


/* 2000: TBD */
* Corrections of 2000 and 2003 change in categories (TBD important are also 330, 463.. that have different meaning now than then)
foreach y in 2000 {
clear all
use "$sru/`y'/sru`y'.dta"

* Corrections of 2000 change in categories (important are also 209, 208 -- 135, 209, 651)

* Ryby - from 207+208+209 to 207+208
sort zprav
by zprav: gen exp3 = exp if sru == 207 | sru == 208
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 207
drop if sru == 208  
drop exp3 exp4
replace sru = 208 if sru == 209

* Vegetable category changed its name
replace sru = 644 if sru == 651
 
* Joghurt and milk category changed its name
* replace sru = 227 if sru == 226

* One extra weird observation
drop if sru == 135 & pkoef == 0 & zprav == 3114701

* Kva a podobne - zmena od 2001
replace sru = 270 if sru == 275
drop if sru == 275
replace sru = 276 if sru == 274


save "$sru/`y'/sru`y'.dta", replace
}
*/

* Corrections of 2003 change in categories
foreach y in 2003 {
clear all
use "$sru/`y'/sru`y'.dta"

sort zprav
by zprav: gen exp3 = exp if sru == 134 | sru == 135 | sru == 139
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 139
drop if sru == 134 | sru == 135 
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 329 | sru == 339
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 339
drop if sru == 329
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 350 | sru == 385
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 385
drop if sru == 350
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 382 | sru == 368 | sru == 369
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 382
drop if sru == 368 | sru == 369
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 379 | sru == 366 | sru == 367
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 379
drop if sru == 366 | sru == 367
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 383 | sru == 380
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 383
drop if sru == 380
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 409 | sru == 411
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 411
drop if sru == 409
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 410 | sru == 412
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 412
drop if sru == 410
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 419 | sru == 413
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 413
drop if sru == 419
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 420 | sru == 415
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 415
drop if sru == 420
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 447 | sru == 448 | sru == 449 | sru == 455
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 455
drop if sru == 447 | sru == 448 | sru == 449
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 452 | sru == 457
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 452
drop if sru == 457
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 453 | sru == 458
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 453
drop if sru == 458
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 454 | sru == 459
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 454
drop if sru == 459
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 465 | sru == 466
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 465
drop if sru == 466
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 464 | sru == 467 | sru == 468
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 464
drop if  sru == 467 | sru == 468
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 461 | sru == 469
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 461
drop if sru == 469
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 462 | sru == 470
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 462
drop if sru == 470
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 461 | sru == 469
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 461
drop if sru == 469
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 463 | sru == 477 | sru == 478 | sru == 479
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 463
drop if sru == 477 | sru == 478 | sru == 479
drop exp3 exp4

sort zprav
by zprav: gen exp3 = exp if sru == 330 | sru == 334
by zprav: egen exp4 = total(exp3)
by zprav: replace exp = exp4 if sru == 334
drop if sru == 330
drop exp3 exp4

save "$sru/`y'/sru`y'.dta", replace
}





********** Merge SRU, CPI and DPH data ************************************************************
********** Insheet the Match file for SRU, CPI and DPH data and CPI data ************************************************************
clear all
insheet using "$data/Merge/sru_cpi_dph.txt"
save "$data/Merge/sru_cpi_dph.dta", replace

********** Merge Match file with SRU data ************************************************************
foreach y in $years { 
clear all
use "$data/Merge/sru_cpi_dph.dta"
sort sru
merge m:m sru using "$sru/`y'/sru`y'.dta", gen(merge2_sru`y')

drop if merge2_sru`y' != 3

/*
*keep if (sru_2009_2010 == 9 | sru_2009_2010 == 0) 
* Dropping unmerged commodities
* 2009 (2 dropped - Naturln byt NATURLN SPOTEBA and Nevim co to je za polozku, ale v datech je!)
drop if ((sru == 699 | sru == 770) & merge2_sru`y' == 1)
* 2008 (2 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124) and Nevim co to je za polozku, ale v datech je!)
drop if ((sru == 127  | sru == 770) & merge2_sru`y'== 1) 
* 2007 (9 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124), Naturln byt NATURLN SPOTEBA, Nevim co to je za polozku, ale v datech je! and 6 variables related to regulacni poplatky ve zdravotnictvi)
drop if ((sru == 127 | sru == 699 | sru == 770 | sru == 158 | sru == 330 | sru == 476 | sru == 477 | sru == 478 | sru == 479) & merge2_sru`y'== 1) 
* 2006 (9 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124), Naturln byt NATURLN SPOTEBA, Nevim co to je za polozku, ale v datech je! and 6 variables related to regulacni poplatky ve zdravotnictvi)
drop if ((sru == 127 | sru == 699 | sru == 770 | sru == 158 | sru == 330 | sru == 476 | sru == 477 | sru == 478 | sru == 479) & merge2_sru`y'== 1) 
* 2005 (10 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124), Sluby penosu dat, internetov spojen, dvakrt Nevim co to je za polozku, ale v datech je! and 6 variables related to regulacni poplatky ve zdravotnictvi)
drop if ((sru == 127 | sru == 425 | sru == 760 | sru == 770 | sru == 158 | sru == 330 | sru == 476 | sru == 477 | sru == 478 | sru == 479) & merge2_sru`y'== 1) 
* 2004 (10 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124), Sluby penosu dat, internetov spojen, dvakrt Nevim co to je za polozku, ale v datech je! and 6 variables related to regulacni poplatky ve zdravotnictvi)
drop if ((sru == 127 | sru == 425 | sru == 760 | sru == 770 | sru == 158 | sru == 330 | sru == 476 | sru == 477 | sru == 478 | sru == 479) & merge2_sru`y'== 1) 
* 2003 (9 dropped)
* 2002 (13 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124), Naturln byt NATURLN SPOTEBA, Dtsk korky a nostka, Mobiln telefony, Provoz mobilnho telefonu, Sluby penosu dat, internetov spojen, dvakrt Nevim co to je za polozku, ale v datech je! and 6 variables related to regulacni poplatky ve zdravotnictvi)
drop if ((sru == 127 | sru == 699 | sru == 366 | sru == 370 | sru == 424 | sru == 158 | sru == 770 | sru == 330 | sru == 476 | sru == 477 | sru == 478 | sru == 479) & merge2_sru`y'== 1) 
* 2001 (12 dropped - Nhrada mzdy pi pracovn neschopnosti (od roku 2009 odstepeno od 124), Dtsk korky a nostka, Mobiln telefony, Provoz mobilnho telefonu, Sluby penosu dat, internetov spojen, dvakrt Nevim co to je za polozku, ale v datech je! and 6 variables related to regulacni poplatky ve zdravotnictvi)
drop if ((sru == 127 | sru == 366 | sru == 370 | sru == 424 | sru == 158 | sru == 770 | sru == 330 | sru == 476 | sru == 477 | sru == 478 | sru == 479) & merge2_sru`y'== 1) 
* 2000 20 dropped above and these 8 additional (Ostatn mln vrobky, Rajata, papriky, okurky a ostatn plodov zelenina, Ostatn zelenina, Zeleninov vrobky, Sl, koen, Ppravky k doplnn a ochucen jdel, Automobily nov, Zkladn kola 1. - 5. ronk
drop if ((sru == 227 | sru == 243 | sru == 244 | sru == 245 | sru == 274 | sru == 275 | sru == 360 | sru ==  450) & merge2_sru`y'== 1) 
*/
save "$sru/`y'/sru2_`y'.dta", replace
}

foreach y in 2010 2011 {
clear all
use "$data/Merge/sru_cpi_dph.dta"
keep if (sru_2009_2010 == 10 | sru_2009_2010 == 0) 
sort sru_2010
merge m:m sru_2010 using "$sru/`y'/sru`y'.dta", gen(merge2_sru`y')

* Dropping unmerged commodities
* 2010 (1 dropped - Naturln byt NATURLN SPOTEBA)
drop if (sru_2010 == 6990 & merge2_sru`y' == 1 & y == 2010) 

save "$sru/`y'/sru2_`y'.dta", replace
}






********** Insheet CPI data a (simpler b ready as an alternative) ************************************************************
clear all
insheet using "$cpi/cpi_a.txt" 
sort cpi_a_coicop praha year
save "$cpi/cpi_a.dta", replace


********** Merge CPI data with SRU data also with Prague ************************************************************
foreach y in $years {
clear all
use "$sru/`y'/sru2_`y'.dta"
sort cpi_a_coicop praha year
merge m:m cpi_a_coicop praha year using "$cpi/cpi_a.dta", gen(merge_cpi_a)

* Dropping a lot observations, mostly those outside groups and those without prices or prices in different years
drop if merge_cpi_a != 3

* Dropping any negative expenditures (TBD, around 100-500 every year)
drop if exp < 0

save "$sru/`y'/sru3_`y'.dta", replace
}




********** Groups and attempt to work with SRU data ************************************************************
foreach y in $years {
clear all
set mem 1G
set more off
use "$sru/`y'/sru3_`y'.dta"

* The choice of the groups - type of groups TBD
foreach n in 1 11 15  { // these are the types of groups we created 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 21 22 23 24 25 26 27 ,,, 2: 6 7 8 9 10 11 12 13
* Group related variables - total expenditure
sort zprav
by zprav: egen exp_total`n' = total(exp)  if group_`n' >= 1 & group_`n' <= 8
by zprav: egen exptotal`n' = min(exp_total`n')

egen pg_n`n' = wtmean(cpi_a_price) if group_`n' >= 1 & group_`n' <= 8, weight(exp)  
egen pgn`n' = min(pg_n`n')

capture drop exp_total? pg_n?
capture drop exp_total?? pg_n??

foreach g in 1 2 3 4 5 6 7 8 { //
* Group related variables - shares w
sort zprav
by zprav: egen exp_`g'_n`n' = total(exp)  if group_`n' == `g'
by zprav: egen exp`g'_n`n' = min(exp_`g'_n`n')
by zprav: gen w_`g'_n`n' = exp`g'_n`n'/exptotal`n' if group_`n' == `g'
by zprav: egen w`g'_n`n' = min(w_`g'_n`n')

* Group related variables - CPI prices - household level
by zprav: egen p_`g'_n`n' = wtmean(cpi_a_price) if group_`n' == `g', weight(exp)  
by zprav: egen p`g'_n`n' = min(p_`g'_n`n')

* Group related variables - CPI prices - aggregate level
egen pa_`g'_n`n' = wtmean(cpi_a_price) if group_`n' == `g', weight(exp)  
egen pa`g'_n`n' = min(pa_`g'_n`n')


capture drop exp_?_n? w_?_n? p_?_n? pa_?_n? 
capture drop exp_?_n?? w_?_n?? p_?_n?? pa_?_n??

}
}
save "$sru/`y'/sru4_`y'.dta", replace
}


********** Reshaping back to wide from long after DPH multiplication ******************************************************************************** 
foreach y in $years  {
clear all
use "$sru/`y'/sru4_`y'.dta"

drop amount_yes dph cpi_a_price cpi_b merge_cpi_a _merge cpi_a_coicop  cpi_a_description base_year polo_coicop
drop sru
capture drop group_? group_??
drop sru_popis_2010 sru_popis_2009 sru_2009_2010
capture drop merge2_sru???? 

reshape wide amount exp, i(zprav) j(sru_2010)

save "$sru/`y'/sru5_`y'.dta", replace
}



* Empty the existing Master file
clear all
use "$data/Merge/sru_all_6.dta"
drop if year > 0
keep year 
save "$data/Merge/sru_all_6.dta", replace

* Merge the files into one Master file
foreach y in $years {
clear all
use "$data/Merge/sru_all_6.dta"
append using "$sru/`y'/sru5_`y'.dta"
save "$data/Merge/sru_all_6.dta", replace
}

* Changes to the dataset for all years for QUAIDS
* Vymazn doplkovho souboru nzkopjmovch skupin s dtmi (TBD) (* Representative data - pkoef, not accounted for here TBD)
drop if skup == 0
********** Preparation for Demand model - variables ******************************************************************************** 
* Other variables
gen adults = osob - deti
gen sex = 0
replace sex = 1 if pohl_p == 1
gen empstat = 1
replace empstat = 0 if zam_p == 0
gen educlow = 0
replace educlow = 1 if vzd_p <= 2
gen educmid = 0
replace educmid = 1 if vzd_p  >= 3 & vzd_p <= 5
gen educ = 1 if educlow == 1
replace educ = 2 if educmid == 1
replace educ = 3 if vzd_p  > 5

* Children
gen deti2 = 0 if deti == 0 
replace deti2 = 1 if deti > 0 & deti <= 1
replace deti2 = 2 if deti > 1 & deti <= 2
replace deti2 = 3 if deti > 2 & deti <= 3
replace deti2 = 4 if deti > 3 & deti <= 4
replace deti2 = 5 if deti > 4 & deti <= 5
replace deti2 = 6 if deti > 5
gen child2 = deti2
gen child = deti
* Members of households
gen osob2 = 1 if osob >= 0 & osob <= 1
replace osob2 = 2 if osob > 1 & osob <= 2
replace osob2 = 3 if osob > 2 & osob <= 3
replace osob2 = 4 if osob > 3 & osob <= 4
replace osob2 = 5 if osob > 4 & osob <= 5
replace osob2 = 6 if osob > 5 & osob <= 6
replace osob2 = 7 if osob > 6 & osob <= 7
replace osob2 = 8 if osob > 7
* Age of head of household
gen age = vek_p
gen age2 = 1 if age >= 0 & age <= 40
replace age2 = 2 if age > 40 & age <= 60
replace age2 = 3 if age > 60
* Regions - dummies for regions on the basis of the above definitions (14 kraju)
tabulate kraj, gen(kraj)

* Time trend variable
gen rok_year = 2012 - year

* City size - 1 village, 2 city, 3 regional capital
gen city_size = typ


save "$data/Merge/sru_all_11.dta", replace

